==> jc-1.4.0.tar.gz: gnu/java/net/protocol/ftp/PassiveModeDTP.h <==
// final class gnu.java.net.protocol.ftp.PassiveModeDTP

// class file dependencies
// @dep_class 88030aec0ded1efd gnu_java_net_protocol_ftp_PassiveModeDTP
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_ftp_PassiveModeDTP_H_
#define _JC_gnu_java_net_protocol_ftp_PassiveModeDTP_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$object;
struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_InetAddress$object;
struct _jc_java_net_Socket$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$sub_refs	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$refs	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$nonrefs	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object;

typedef const struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vmethods	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vtable	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vtype	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method$_init$3200e690ccbe7666(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *, struct _jc_java_lang_String$object *, jint, struct _jc_java_net_InetAddress$object *, jint, jint);

// Virtual methods
extern jboolean _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method$abort$e796432fcfca78e8(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *);
extern void _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method$complete$51c4339c04062948(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *);
extern struct _jc_java_io_InputStream$object *_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method$getInputStream$13cf75a12cabb343(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *);
extern struct _jc_java_io_OutputStream$object *_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method$getOutputStream$1f50a8d1fe1542e3(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *);
extern void _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method$setTransferMode$02f0de2cb653dfc0(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *, jint);
extern void _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method$transferComplete$ae2c162c293821ce(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method_info$abort$e796432fcfca78e8;
extern _jc_method _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method_info$complete$51c4339c04062948;
extern _jc_method _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method_info$getInputStream$13cf75a12cabb343;
extern _jc_method _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method_info$getOutputStream$1f50a8d1fe1542e3;
extern _jc_method _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method_info$setTransferMode$02f0de2cb653dfc0;
extern _jc_method _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method_info$transferComplete$ae2c162c293821ce;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vmethods {
	jboolean	(*abort$e796432fcfca78e8)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *);
	void	(*complete$51c4339c04062948)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *);
	struct _jc_java_io_InputStream$object	*(*getInputStream$13cf75a12cabb343)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *);
	struct _jc_java_io_OutputStream$object	*(*getOutputStream$1f50a8d1fe1542e3)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *);
	void	(*setTransferMode$02f0de2cb653dfc0)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *, jint);
	void	(*transferComplete$ae2c162c293821ce)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *);
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vmethods	gnu_java_net_protocol_ftp_PassiveModeDTP;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$sub_refs {
	struct _jc_java_lang_String$object	*address;
	struct _jc_java_net_Socket$object	*socket;
	struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$object	*in;
	struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$object	*out;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$refs {
    _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$sub_refs	gnu_java_net_protocol_ftp_PassiveModeDTP;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$sub_nonrefs {
	jint	port;
	jboolean	completed;
	jboolean	inProgress;
	jint	transferMode;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$sub_nonrefs	gnu_java_net_protocol_ftp_PassiveModeDTP;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object {
	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vtype _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_PassiveModeDTP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_PassiveModeDTP_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/ftp/PassiveModeDTP.h <==
// final class gnu.java.net.protocol.ftp.PassiveModeDTP

// class file dependencies
// @dep_class 88030aec0ded1efd gnu_java_net_protocol_ftp_PassiveModeDTP
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_ftp_PassiveModeDTP_H_
#define _JC_gnu_java_net_protocol_ftp_PassiveModeDTP_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$object;
struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$object;
struct _jc_java_io_InputStream$object;
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_InetAddress$object;
struct _jc_java_net_Socket$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$sub_refs	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$sub_refs;
typedef struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$sub_nonrefs	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$refs	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$refs;
typedef struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$nonrefs	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$nonrefs;
typedef struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object;

typedef const struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vmethods	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vmethods;
typedef const struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vtable	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vtable;
typedef const struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vtype	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method$_init$3200e690ccbe7666(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *, struct _jc_java_lang_String$object *, jint, struct _jc_java_net_InetAddress$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method$abort$e796432fcfca78e8(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method$complete$51c4339c04062948(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_InputStream$object *_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method$getInputStream$13cf75a12cabb343(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_OutputStream$object *_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method$getOutputStream$1f50a8d1fe1542e3(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method$setTransferMode$02f0de2cb653dfc0(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method$transferComplete$ae2c162c293821ce(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method_info$abort$e796432fcfca78e8;
extern _jc_method _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method_info$complete$51c4339c04062948;
extern _jc_method _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method_info$getInputStream$13cf75a12cabb343;
extern _jc_method _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method_info$getOutputStream$1f50a8d1fe1542e3;
extern _jc_method _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method_info$setTransferMode$02f0de2cb653dfc0;
extern _jc_method _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$method_info$transferComplete$ae2c162c293821ce;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vmethods {
	jboolean	(*abort$e796432fcfca78e8)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *) _JC_JCNI_ATTR;
	void	(*complete$51c4339c04062948)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *) _JC_JCNI_ATTR;
	struct _jc_java_io_InputStream$object	*(*getInputStream$13cf75a12cabb343)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *) _JC_JCNI_ATTR;
	struct _jc_java_io_OutputStream$object	*(*getOutputStream$1f50a8d1fe1542e3)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *) _JC_JCNI_ATTR;
	void	(*setTransferMode$02f0de2cb653dfc0)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *, jint) _JC_JCNI_ATTR;
	void	(*transferComplete$ae2c162c293821ce)(_jc_env *, struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vmethods	gnu_java_net_protocol_ftp_PassiveModeDTP;
};

// Vtype
struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$sub_refs {
	struct _jc_java_lang_String$object	*address;
	struct _jc_java_net_Socket$object	*socket;
	struct _jc_gnu_java_net_protocol_ftp_DTPInputStream$object	*in;
	struct _jc_gnu_java_net_protocol_ftp_DTPOutputStream$object	*out;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$refs {
    _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$sub_refs	gnu_java_net_protocol_ftp_PassiveModeDTP;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$sub_nonrefs {
	jint	port;
	jboolean	completed;
	jboolean	inProgress;
	jint	transferMode;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$sub_nonrefs	gnu_java_net_protocol_ftp_PassiveModeDTP;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$object {
	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vtype	*vtype;
	_jc_gnu_java_net_protocol_ftp_PassiveModeDTP$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$vtype _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_ftp_PassiveModeDTP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_ftp_PassiveModeDTP$class_object;

#endif	/* _JC_gnu_java_net_protocol_ftp_PassiveModeDTP_H_ */
